@@ -1,11 +1,12 @@
-import responses
-import requests
+import respx
+import httpx
 import pytest
 
+from wapitiCore.parsers.html_parser import Html
 from wapitiCore.net.xss_utils import get_context_list, valid_xss_content_type, meet_requirements, \
     find_separator
-from wapitiCore.net.csp_utils import has_csp
-from wapitiCore.net.crawler import Page
+from wapitiCore.net.csp_utils import has_csp_header, has_csp_meta
+from wapitiCore.net.crawler import Response
 
 
 def test_title_context():
@@ -515,86 +516,66 @@ def test_get_context_bug_2():
     ]
 
 
-@responses.activate
+@respx.mock
 def test_csp_detection():
     url = "http://perdu.com/"
-    responses.add(
-        responses.GET,
-        url,
-        status=200,
-        adding_headers={
-            "Content-Type": "text/html"
-        }
-    )
+    respx.get(url).mock(return_value=httpx.Response(200, headers={"Content-Type": "text/html"}))
 
-    resp = requests.get(url)
-    page = Page(resp)
-    assert not has_csp(page)
+    response = Response(httpx.get(url))
+    assert not has_csp_header(response)
+    assert not has_csp_meta(Html(response.content, url))
 
     url = "http://perdu.com/http_csp"
-    responses.add(
-        responses.GET,
-        url,
-        status=200,
-        adding_headers={
-            "Content-Type": "text/html",
-            "Content-Security-Policy": "blahblah;"
-        }
+    respx.get(url).mock(
+        return_value=httpx.Response(
+            200,
+            headers={
+                "Content-Type": "text/html",
+                "Content-Security-Policy": "blahblah;"
+            }
+        )
     )
 
-    resp = requests.get(url)
-    page = Page(resp)
-    assert has_csp(page)
+    response = Response(httpx.get(url))
+    assert has_csp_header(response)
+    assert not has_csp_meta(Html(response.content, url))
 
     url = "http://perdu.com/meta_csp"
-    responses.add(
-        responses.GET,
-        url,
-        status=200,
-        adding_headers={
-            "Content-Type": "text/html"
-        },
-        body="""<html>
-        <head>
-        <meta http-equiv="Content-Security-Policy" content="default-src 'self'; img-src https://*; child-src 'none';">
-        </head>
-        <body>Hello there</body>
-        </html>"""
+
+    respx.get(url).mock(
+        return_value=httpx.Response(
+            200,
+            headers={
+                "Content-Type": "text/html"
+            },
+            text="""<html>
+            <head>
+            <meta http-equiv="Content-Security-Policy" content="default-src 'self'; img-src https://*; child-src 'none';">
+            </head>
+            <body>Hello there</body>
+            </html>"""
+        )
     )
 
-    resp = requests.get(url)
-    page = Page(resp)
-    assert has_csp(page)
+    response = Response(httpx.get(url))
+    assert not has_csp_header(response)
+    assert has_csp_meta(Html(response.content, url))
 
 
-@responses.activate
+@respx.mock
 def test_valid_content_type():
     url = "http://perdu.com/"
-    responses.add(
-        responses.GET,
-        url,
-        status=200,
-        adding_headers={
-            "Content-Type": "text/html"
-        }
-    )
+    respx.get(url).mock(return_value=httpx.Response(200, headers={"Content-Type": "text/html"}))
 
-    resp = requests.get(url)
-    page = Page(resp)
+    resp = httpx.get(url)
+    page = Response(resp)
     assert valid_xss_content_type(page)
 
     url = "http://perdu.com/picture.png"
-    responses.add(
-        responses.GET,
-        url,
-        status=200,
-        adding_headers={
-            "Content-Type": "image/png"
-        }
-    )
+    respx.get(url).mock(return_value=httpx.Response(200, headers={"Content-Type": "image/png"}))
 
-    resp = requests.get(url)
-    page = Page(resp)
+    resp = httpx.get(url)
+    page = Response(resp)
     assert not valid_xss_content_type(page)
 
 
@@ -617,13 +598,13 @@ def test_payload_requirements():
     context_list = get_context_list(code, "injected")
     assert context_list[0]["special_attributes"] == {"type=text"}
     # Requirement met as input type is not "hidden" and style is missing
-    assert meet_requirements(["!style", "type!=hidden"], context_list[0]["special_attributes"]) is ""
+    assert meet_requirements(["!style", "type!=hidden"], context_list[0]["special_attributes"]) == ""
 
     code = '<input value="injected"/>'
     context_list = get_context_list(code, "injected")
     # Requirement met as there is no special attributes to make our life harder
     assert "special_attributes" not in context_list[0]
-    assert meet_requirements(["!style", "type!=hidden"], []) is ""
+    assert meet_requirements(["!style", "type!=hidden"], []) == ""
 
 
 def test_find_separator():
