@@ -114,7 +114,6 @@ class ModuleExec(Attack):
                         vuln_message = f"{vuln_info} via injection in the parameter {parameter.display_name}"
 
                     await self.add_critical(
-                        request_id=request.path_id,
                         finding_class=CommandExecutionFinding,
                         request=mutated_request,
                         info=vuln_message,
@@ -152,7 +151,6 @@ class ModuleExec(Attack):
                     anom_msg = Messages.MSG_PARAM_TIMEOUT.format(parameter.display_name)
 
                 await self.add_medium(
-                    request_id=request.path_id,
                     finding_class=ResourceConsumptionFinding,
                     request=mutated_request,
                     info=anom_msg,
@@ -168,7 +166,7 @@ class ModuleExec(Attack):
                 vuln_info = None
 
                 # No timeout raised, check for patterns in response
-                if any(rule in response.content for rule in payload_info.rules):
+                if any(rule.replace("[SPACE]", " ") in response.content for rule in payload_info.rules):
                     vuln_info = payload_info.description
                     # We reached maximum exploitation for this parameter, don't send more payloads
                     vulnerable_parameter = True
@@ -189,7 +187,6 @@ class ModuleExec(Attack):
                         log_message = Messages.MSG_PARAM_INJECT
 
                     await self.add_critical(
-                        request_id=request.path_id,
                         finding_class=CommandExecutionFinding,
                         request=mutated_request,
                         info=vuln_message,
@@ -215,7 +212,6 @@ class ModuleExec(Attack):
                         anom_msg = Messages.MSG_PARAM_500.format(parameter.display_name)
 
                     await self.add_high(
-                        request_id=request.path_id,
                         finding_class=InternalErrorFinding,
                         request=mutated_request,
                         info=anom_msg,
