@@ -28,17 +28,17 @@ from urllib.parse import urlparse, quote_plus
 from aiocache import cached
 from httpx import RequestError
 
-from arsenic import get_session, browsers, services
-from arsenic.errors import JavascriptError, UnknownError, ArsenicError
+from wapiti_arsenic import get_session, browsers, services
+from wapiti_arsenic.errors import JavascriptError, UnknownError, ArsenicError
 
 from wapitiCore.attack.cve.checker import (
     CVEChecker, cvss_score_to_wapiti_level, CVE_DIRECTORY, SUPPORTED_SOFTWARES, is_cve_supported_software
 )
+from wapitiCore.controller.exceptions import InvalidOptionValue
 from wapitiCore.definitions.vulnerable_software_version import VulnerableSoftwareFinding
 from wapitiCore.main.log import logging, log_blue, log_severity
-from wapitiCore.main.wapiti import is_valid_url
+from wapitiCore.net.web import is_valid_url
 from wapitiCore.attack.attack import Attack
-from wapitiCore.controller.wapiti import InvalidOptionValue
 from wapitiCore.net.response import Response
 from wapitiCore.wappalyzer.wappalyzer import Wappalyzer, ApplicationData, ApplicationDataException
 from wapitiCore.definitions.fingerprint import SoftwareNameDisclosureFinding
@@ -321,6 +321,9 @@ class ModuleWapp(Attack):
                         response=response
                     )
 
+                if application_name == "Apache HTTP Server":
+                    application_name = "apache"
+
                 if is_cve_supported_software(application_name):
                     if await self.download_latest_release_asset(application_name.lower(), self.user_config_dir):
                         async for severity, message in self.get_vulnerabilities(application_name.lower(), versions):
