@@ -34,9 +34,9 @@ from mitmproxy.master import Master
 from mitmproxy.options import Options
 from mitmproxy.http import Request as MitmRequest
 import httpx
-from arsenic import get_session, browsers, services
-from arsenic.constants import SelectorType
-from arsenic.errors import ArsenicError, ElementNotInteractable, UnknownArsenicError, NoSuchElement
+from wapiti_arsenic import get_session, browsers, services
+from wapiti_arsenic.constants import SelectorType
+from wapiti_arsenic.errors import ArsenicError, ElementNotInteractable, UnknownArsenicError, NoSuchElement
 import structlog
 
 from wapitiCore.net import Request
@@ -68,7 +68,7 @@ def is_interpreted_type(mime_type: str) -> bool:
 
 def set_arsenic_log_level(level: int = WARNING):
     # Create logger
-    logger = getLogger('arsenic')
+    logger = getLogger('wapiti_arsenic')
 
     # We need factory, to return application-wide logger
     def logger_factory():
@@ -249,9 +249,10 @@ def extract_requests(html: Html, request: Request):
             yield next_request
 
     for form in html.iter_forms():
-        # if scope.check(form) and form not in to_explore and form not in excluded_requests:
-        form.link_depth = request.link_depth + 1
-        yield form
+        for form_request in form.to_requests():
+            # if scope.check(form) and form not in to_explore and form not in excluded_requests:
+            form_request.link_depth = request.link_depth + 1
+            yield form_request
 
 
 async def click_in_webpage(headless_client, request: Request, wait_time: float, timeout: float):
@@ -279,6 +280,7 @@ async def click_in_webpage(headless_client, request: Request, wait_time: float,
                     await headless_client.get(request.url_with_fragment, timeout=timeout)
 
 
+# pylint: disable=too-many-positional-arguments
 async def launch_headless_explorer(
         stop_event: asyncio.Event,
         crawler: AsyncCrawler,
@@ -380,6 +382,7 @@ async def launch_headless_explorer(
 
 
 class InterceptingExplorer(Explorer):
+    # pylint: disable=too-many-positional-arguments
     def __init__(
             self,
             crawler_configuration: CrawlerConfiguration,
