@@ -24,9 +24,10 @@ from urllib.parse import urlparse, urlunparse, unquote, quote, urljoin
 from typing import Optional, List, Tuple, Union
 import re
 
-
 import httpx
 
+from wapitiCore.main.log import logging
+
 Parameters = Optional[Union[List[List[str]], str]]
 
 
@@ -249,6 +250,7 @@ def make_absolute(base: str, url: str, allow_fragments=True) -> str:
 
 
 class Request:
+    # pylint: disable=too-many-positional-arguments
     def __init__(
             self,
             path: str,
@@ -392,12 +394,12 @@ class Request:
     # having read-only params in Request class would be more Pythonic. More work on the Mutator in a future version ?
     def __hash__(self):
         if self._cached_hash is None:
-            get_kv = tuple([tuple(param) for param in self._get_params])
+            get_kv = tuple(tuple(param) for param in self._get_params)
             if isinstance(self._post_params, list):
-                post_kv = tuple([tuple(param) for param in self._post_params])
+                post_kv = tuple(tuple(param) for param in self._post_params)
             else:
                 post_kv = self._enctype + str(len(self._post_params))
-            file_kv = tuple([tuple([param[0], param[1][0]]) for param in self._file_params])
+            file_kv = tuple(tuple([param[0], param[1][0]]) for param in self._file_params)
 
             self._cached_hash = hash((self._method, self._resource_path, get_kv, post_kv, file_kv))
         return self._cached_hash
@@ -790,3 +792,19 @@ class Request:
     @path_id.setter
     def path_id(self, value: int):
         self._path_id = value
+
+
+def is_valid_url(url: str):
+    """Verify if the url provided has the right format"""
+    try:
+        parts = urlparse(url)
+        _ = parts.port
+    except ValueError:
+        logging.error(f"Invalid port number given in URL {url}")
+        return False
+
+    if parts.scheme in ("http", "https") and parts.netloc:
+        return True
+
+    logging.error(f"Error: {url} is not a valid URL")
+    return False
